/*
 *  
 *  $Id$
 *  Ginkgo CADx Project
 *
 *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
 *  http://ginkgo-cadx.com
 *
 *  This file is licensed under LGPL v3 license.
 *  See License.txt for details
 *
 */
#pragma once

#if defined(_WINDOWS)
	#pragma warning (disable : 4231)
	#pragma warning (disable : 4275)
	#pragma warning (disable : 4251)

	#if defined(APIEXPORT)
		#define EXTAPI _declspec(dllexport)
		#define EXTAPI_TEMPLATE
	#else
		#define EXTAPI _declspec(dllimport)
		#define EXTAPI_TEMPLATE extern
	#endif
#else
	#if defined(APIEXPORT)
		#define EXTAPI __attribute__((visibility("default")))
		#define EXTAPI_TEMPLATE
	#else
		#define EXTAPI
		#define EXTAPI_TEMPLATE extern
	#endif
#endif

#include <api/internacionalization/internacionalization.h>
#include <api/iexception.h>
